/* gnome-boxes-search-provider.c generated by valac 0.30.0, the Vala compiler
 * generated from gnome-boxes-search-provider.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libcommon.h>
#include <stdio.h>


#define BOXES_TYPE_SEARCH_PROVIDER (boxes_search_provider_get_type ())
#define BOXES_SEARCH_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProvider))
#define BOXES_SEARCH_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProviderClass))
#define BOXES_IS_SEARCH_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCH_PROVIDER))
#define BOXES_IS_SEARCH_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCH_PROVIDER))
#define BOXES_SEARCH_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProviderClass))

typedef struct _BoxesSearchProvider BoxesSearchProvider;
typedef struct _BoxesSearchProviderClass BoxesSearchProviderClass;
typedef struct _BoxesSearchProviderPrivate BoxesSearchProviderPrivate;

#define BOXES_TYPE_SEARCH_PROVIDER_APP (boxes_search_provider_app_get_type ())
#define BOXES_SEARCH_PROVIDER_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCH_PROVIDER_APP, BoxesSearchProviderApp))
#define BOXES_SEARCH_PROVIDER_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCH_PROVIDER_APP, BoxesSearchProviderAppClass))
#define BOXES_IS_SEARCH_PROVIDER_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCH_PROVIDER_APP))
#define BOXES_IS_SEARCH_PROVIDER_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCH_PROVIDER_APP))
#define BOXES_SEARCH_PROVIDER_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCH_PROVIDER_APP, BoxesSearchProviderAppClass))

typedef struct _BoxesSearchProviderApp BoxesSearchProviderApp;
typedef struct _BoxesSearchProviderAppClass BoxesSearchProviderAppClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
typedef struct _BoxesSearchProviderLoadData BoxesSearchProviderLoadData;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
typedef struct _BoxesSearchProviderSearchData BoxesSearchProviderSearchData;
typedef struct _boxes_search_provider_GetInitialResultSetData boxes_search_provider_GetInitialResultSetData;
typedef struct _boxes_search_provider_GetSubsearchResultSetData boxes_search_provider_GetSubsearchResultSetData;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesSearchProviderGetMetasData BoxesSearchProviderGetMetasData;
typedef struct _boxes_search_provider_GetResultMetasData boxes_search_provider_GetResultMetasData;
typedef struct _BoxesSearchProviderAppPrivate BoxesSearchProviderAppPrivate;

struct _BoxesSearchProvider {
	GObject parent_instance;
	BoxesSearchProviderPrivate * priv;
};

struct _BoxesSearchProviderClass {
	GObjectClass parent_class;
};

struct _BoxesSearchProviderPrivate {
	BoxesSearchProviderApp* app;
	gboolean loading;
	gboolean _loaded;
	GHashTable* boxes;
	guint next_id;
};

struct _Block1Data {
	int _ref_count_;
	BoxesSearchProvider* self;
	gpointer _async_data_;
};

struct _BoxesSearchProviderLoadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	Block1Data* _data1_;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	gulong wait;
	gulong _tmp3_;
	gulong _tmp4_;
	gboolean _tmp5_;
	GFile* dir;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GFile* _tmp8_;
	GFile* _tmp9_;
	GFile* _tmp10_;
};

struct _Block2Data {
	int _ref_count_;
	GPtrArray* self;
	GCompareFunc compare_func;
};

struct _BoxesSearchProviderSearchData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	gchar** terms;
	gint terms_length1;
	gchar** result;
	gint result_length1;
	BoxesSearchProviderApp* _tmp0_;
	gchar** normalized_terms;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gint normalized_terms_length1;
	gint _normalized_terms_size_;
	GPtrArray* matches;
	GPtrArray* _tmp9_;
	gchar** _tmp10_;
	gint _tmp10__length1;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gboolean _tmp13_;
	GHashTable* _tmp14_;
	GList* _tmp15_;
	GList* box_collection;
	GList* box_it;
	BoxesBoxConfig* box;
	BoxesBoxConfig* _tmp16_;
	gchar** _tmp17_;
	gint _tmp17__length1;
	gboolean _tmp18_;
	GPtrArray* _tmp19_;
	BoxesBoxConfig* _tmp20_;
	BoxesBoxConfig* _tmp21_;
	GPtrArray* _tmp22_;
	gchar** results;
	GPtrArray* _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
	gchar** _tmp26_;
	gint results_length1;
	gint _results_size_;
	gint i;
	gboolean _tmp27_;
	gint _tmp28_;
	gint _tmp29_;
	GPtrArray* _tmp30_;
	gint _tmp31_;
	gint _tmp32_;
	gchar** _tmp33_;
	gint _tmp33__length1;
	gint _tmp34_;
	GPtrArray* _tmp35_;
	gint _tmp36_;
	gconstpointer _tmp37_;
	gconstpointer _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	BoxesSearchProviderApp* _tmp41_;
	gchar** _tmp42_;
	gint _tmp42__length1;
};

struct _boxes_search_provider_GetInitialResultSetData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	gchar** terms;
	gint terms_length1;
	gchar** result;
	gint result_length1;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
};

struct _boxes_search_provider_GetSubsearchResultSetData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	gchar** previous_results;
	gint previous_results_length1;
	gchar** new_terms;
	gint new_terms_length1;
	gchar** result;
	gint result_length1;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
};

struct _BoxesSearchProviderGetMetasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	gchar** ids;
	gint ids_length1;
	GHashTable** result;
	gint result_length1;
	GHashTable** metas;
	gchar** _tmp0_;
	gint _tmp0__length1;
	GHashTable** _tmp1_;
	gint metas_length1;
	gint _metas_size_;
	BoxesSearchProviderApp* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	gchar* _tmp5_;
	guint n;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gchar** id_collection;
	gint id_collection_length1;
	gint _id_collection_size_;
	gint id_it;
	gchar* _tmp7_;
	gchar* id;
	BoxesBoxConfig* box;
	GHashTable* _tmp8_;
	const gchar* _tmp9_;
	gconstpointer _tmp10_;
	BoxesBoxConfig* _tmp11_;
	BoxesBoxConfig* _tmp12_;
	GHashTable* meta;
	GHashFunc _tmp13_;
	GEqualFunc _tmp14_;
	GHashTable* _tmp15_;
	GHashTable** _tmp16_;
	gint _tmp16__length1;
	guint _tmp17_;
	GHashTable* _tmp18_;
	GHashTable* _tmp19_;
	GHashTable* _tmp20_;
	guint _tmp21_;
	GHashTable* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	GVariant* _tmp25_;
	GHashTable* _tmp26_;
	gchar* _tmp27_;
	BoxesBoxConfig* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	GVariant* _tmp32_;
	GFile* file;
	BoxesBoxConfig* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	GFile* _tmp39_;
	GFile* _tmp40_;
	GFileInfo* info;
	GFileInfo* _tmp41_;
	GFile* _tmp42_;
	GFileInfo* _tmp43_;
	GFileInfo* _tmp44_;
	GError* _error_;
	GFileInfo* _tmp45_;
	GFileIcon* icon;
	GFile* _tmp46_;
	GFileIcon* _tmp47_;
	GHashTable* _tmp48_;
	gchar* _tmp49_;
	GFileIcon* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	GVariant* _tmp53_;
	GHashTable* _tmp54_;
	gchar* _tmp55_;
	GThemedIcon* _tmp56_;
	GThemedIcon* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	GVariant* _tmp60_;
	BoxesSearchProviderApp* _tmp61_;
	GHashTable** _tmp62_;
	gint _tmp62__length1;
	guint _tmp63_;
	GHashTable** _tmp64_;
	gint _tmp64__length1;
	GHashTable** _tmp65_;
	gint _tmp65__length1;
	GError * _inner_error_;
};

struct _boxes_search_provider_GetResultMetasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSearchProvider* self;
	gchar** ids;
	gint ids_length1;
	GHashTable** result;
	gint result_length1;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
	GHashTable** _tmp3_;
	GHashTable** _tmp4_;
	gint _tmp4__length1;
};

struct _BoxesSearchProviderApp {
	GApplication parent_instance;
	BoxesSearchProviderAppPrivate * priv;
};

struct _BoxesSearchProviderAppClass {
	GApplicationClass parent_class;
};


static gpointer boxes_search_provider_parent_class = NULL;
static gpointer boxes_search_provider_app_parent_class = NULL;

GType boxes_search_provider_get_type (void) G_GNUC_CONST;
guint boxes_search_provider_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType boxes_search_provider_app_get_type (void) G_GNUC_CONST;
#define BOXES_SEARCH_PROVIDER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProviderPrivate))
enum  {
	BOXES_SEARCH_PROVIDER_DUMMY_PROPERTY,
	BOXES_SEARCH_PROVIDER_LOADED
};
BoxesSearchProvider* boxes_search_provider_new (BoxesSearchProviderApp* app);
BoxesSearchProvider* boxes_search_provider_construct (GType object_type, BoxesSearchProviderApp* app);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
static void boxes_search_provider_add_box (BoxesSearchProvider* self, BoxesBoxConfig* box);
static void boxes_search_provider_load_data_free (gpointer _data);
static void boxes_search_provider_load (BoxesSearchProvider* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_search_provider_load_finish (BoxesSearchProvider* self, GAsyncResult* _res_);
static gboolean boxes_search_provider_load_co (BoxesSearchProviderLoadData* _data_);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
gboolean boxes_search_provider_get_loaded (BoxesSearchProvider* self);
static void ___lambda4_ (Block1Data* _data1_);
static void ____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda5_ (BoxesSearchProvider* self, const gchar* filename, GError** error);
static gboolean ___lambda5__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error);
static void boxes_search_provider_load_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_search_provider_set_loaded (BoxesSearchProvider* self, gboolean value);
static void boxes_search_provider_search_data_free (gpointer _data);
static void boxes_search_provider_search (BoxesSearchProvider* self, gchar** terms, int terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gchar** boxes_search_provider_search_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1);
static gboolean boxes_search_provider_search_co (BoxesSearchProviderSearchData* _data_);
static void boxes_search_provider_search_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint __lambda6_ (BoxesBoxConfig* a, BoxesBoxConfig* b);
static gint ___lambda6__gcompare_func (gconstpointer a, gconstpointer b);
static void boxes_search_provider_GetInitialResultSet_data_free (gpointer _data);
void boxes_search_provider_GetInitialResultSet (BoxesSearchProvider* self, gchar** terms, int terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar** boxes_search_provider_GetInitialResultSet_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1);
static gboolean boxes_search_provider_GetInitialResultSet_co (boxes_search_provider_GetInitialResultSetData* _data_);
static gchar** _vala_array_dup1 (gchar** self, int length);
static void boxes_search_provider_GetInitialResultSet_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_search_provider_GetSubsearchResultSet_data_free (gpointer _data);
void boxes_search_provider_GetSubsearchResultSet (BoxesSearchProvider* self, gchar** previous_results, int previous_results_length1, gchar** new_terms, int new_terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar** boxes_search_provider_GetSubsearchResultSet_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1);
static gboolean boxes_search_provider_GetSubsearchResultSet_co (boxes_search_provider_GetSubsearchResultSetData* _data_);
static gchar** _vala_array_dup2 (gchar** self, int length);
static void boxes_search_provider_GetSubsearchResultSet_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_search_provider_get_metas_data_free (gpointer _data);
void boxes_search_provider_get_metas (BoxesSearchProvider* self, gchar** ids, int ids_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
GHashTable** boxes_search_provider_get_metas_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1);
static gboolean boxes_search_provider_get_metas_co (BoxesSearchProviderGetMetasData* _data_);
static void _g_variant_unref0_ (gpointer var);
static void boxes_search_provider_get_metas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static GHashTable** _vala_array_dup3 (GHashTable** self, int length);
static void boxes_search_provider_GetResultMetas_data_free (gpointer _data);
void boxes_search_provider_GetResultMetas (BoxesSearchProvider* self, gchar** ids, int ids_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
GHashTable** boxes_search_provider_GetResultMetas_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1);
static gboolean boxes_search_provider_GetResultMetas_co (boxes_search_provider_GetResultMetasData* _data_);
static gchar** _vala_array_dup4 (gchar** self, int length);
static void boxes_search_provider_GetResultMetas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_search_provider_ActivateResult (BoxesSearchProvider* self, const gchar* search_id, gchar** terms, int terms_length1, guint32 timestamp);
void boxes_search_provider_LaunchSearch (BoxesSearchProvider* self, gchar** terms, int terms_length1, guint32 timestamp);
static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value);
static void boxes_search_provider_finalize (GObject* obj);
static void _vala_boxes_search_provider_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_search_provider_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _dbus_boxes_search_provider_GetInitialResultSet (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_boxes_search_provider_GetInitialResultSet_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_boxes_search_provider_GetSubsearchResultSet (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_boxes_search_provider_GetSubsearchResultSet_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_boxes_search_provider_get_metas (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_boxes_search_provider_get_metas_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_boxes_search_provider_GetResultMetas (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_boxes_search_provider_GetResultMetas_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void _dbus_boxes_search_provider_ActivateResult (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_boxes_search_provider_LaunchSearch (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void boxes_search_provider_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_search_provider_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_boxes_search_provider_get_loaded (BoxesSearchProvider* self);
static gboolean boxes_search_provider_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_boxes_search_provider_set_loaded (BoxesSearchProvider* self, GVariant* _value);
static void _boxes_search_provider_unregister_object (gpointer user_data);
enum  {
	BOXES_SEARCH_PROVIDER_APP_DUMMY_PROPERTY
};
BoxesSearchProviderApp* boxes_search_provider_app_new (void);
BoxesSearchProviderApp* boxes_search_provider_app_construct (GType object_type);
static gboolean boxes_search_provider_app_real_dbus_register (GApplication* base, GDBusConnection* connection, const gchar* object_path, GError** error);
static void boxes_search_provider_app_real_startup (GApplication* base);
gint _vala_main (void);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetInitialResultSet_terms = {-1, "terms", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetInitialResultSet_result = {-1, "result", "as"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetInitialResultSet_in[] = {&_boxes_search_provider_dbus_arg_info_GetInitialResultSet_terms, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetInitialResultSet_out[] = {&_boxes_search_provider_dbus_arg_info_GetInitialResultSet_result, NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_GetInitialResultSet = {-1, "GetInitialResultSet", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetInitialResultSet_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetInitialResultSet_out)};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_previous_results = {-1, "previous_results", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_new_terms = {-1, "new_terms", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_result = {-1, "result", "as"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_in[] = {&_boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_previous_results, &_boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_new_terms, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_out[] = {&_boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_result, NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_GetSubsearchResultSet = {-1, "GetSubsearchResultSet", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetSubsearchResultSet_out)};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_get_metas_ids = {-1, "ids", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_get_metas_result = {-1, "result", "aa{sv}"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_get_metas_in[] = {&_boxes_search_provider_dbus_arg_info_get_metas_ids, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_get_metas_out[] = {&_boxes_search_provider_dbus_arg_info_get_metas_result, NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_get_metas = {-1, "GetMetas", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_get_metas_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_get_metas_out)};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetResultMetas_ids = {-1, "ids", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_GetResultMetas_result = {-1, "result", "aa{sv}"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetResultMetas_in[] = {&_boxes_search_provider_dbus_arg_info_GetResultMetas_ids, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_GetResultMetas_out[] = {&_boxes_search_provider_dbus_arg_info_GetResultMetas_result, NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_GetResultMetas = {-1, "GetResultMetas", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetResultMetas_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_GetResultMetas_out)};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_ActivateResult_search_id = {-1, "search_id", "s"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_ActivateResult_terms = {-1, "terms", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_ActivateResult_timestamp = {-1, "timestamp", "u"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_ActivateResult_in[] = {&_boxes_search_provider_dbus_arg_info_ActivateResult_search_id, &_boxes_search_provider_dbus_arg_info_ActivateResult_terms, &_boxes_search_provider_dbus_arg_info_ActivateResult_timestamp, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_ActivateResult_out[] = {NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_ActivateResult = {-1, "ActivateResult", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_ActivateResult_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_ActivateResult_out)};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_LaunchSearch_terms = {-1, "terms", "as"};
static const GDBusArgInfo _boxes_search_provider_dbus_arg_info_LaunchSearch_timestamp = {-1, "timestamp", "u"};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_LaunchSearch_in[] = {&_boxes_search_provider_dbus_arg_info_LaunchSearch_terms, &_boxes_search_provider_dbus_arg_info_LaunchSearch_timestamp, NULL};
static const GDBusArgInfo * const _boxes_search_provider_dbus_arg_info_LaunchSearch_out[] = {NULL};
static const GDBusMethodInfo _boxes_search_provider_dbus_method_info_LaunchSearch = {-1, "LaunchSearch", (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_LaunchSearch_in), (GDBusArgInfo **) (&_boxes_search_provider_dbus_arg_info_LaunchSearch_out)};
static const GDBusMethodInfo * const _boxes_search_provider_dbus_method_info[] = {&_boxes_search_provider_dbus_method_info_GetInitialResultSet, &_boxes_search_provider_dbus_method_info_GetSubsearchResultSet, &_boxes_search_provider_dbus_method_info_get_metas, &_boxes_search_provider_dbus_method_info_GetResultMetas, &_boxes_search_provider_dbus_method_info_ActivateResult, &_boxes_search_provider_dbus_method_info_LaunchSearch, NULL};
static const GDBusSignalInfo * const _boxes_search_provider_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _boxes_search_provider_dbus_property_info_loaded = {-1, "Loaded", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo * const _boxes_search_provider_dbus_property_info[] = {&_boxes_search_provider_dbus_property_info_loaded, NULL};
static const GDBusInterfaceInfo _boxes_search_provider_dbus_interface_info = {-1, "org.gnome.Shell.SearchProvider2", (GDBusMethodInfo **) (&_boxes_search_provider_dbus_method_info), (GDBusSignalInfo **) (&_boxes_search_provider_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_search_provider_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_search_provider_dbus_interface_vtable = {boxes_search_provider_dbus_interface_method_call, boxes_search_provider_dbus_interface_get_property, boxes_search_provider_dbus_interface_set_property};

static gpointer _g_object_ref0 (gpointer self) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return self ? g_object_ref (self) : NULL;
#line 490 "gnome-boxes-search-provider.c"
}


static void _g_free0_ (gpointer var) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	var = (g_free (var), NULL);
#line 497 "gnome-boxes-search-provider.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 504 "gnome-boxes-search-provider.c"
}


BoxesSearchProvider* boxes_search_provider_construct (GType object_type, BoxesSearchProviderApp* app) {
	BoxesSearchProvider * self = NULL;
	BoxesSearchProviderApp* _tmp0_ = NULL;
	BoxesSearchProviderApp* _tmp1_ = NULL;
	GHashFunc _tmp2_ = NULL;
	GEqualFunc _tmp3_ = NULL;
	GHashTable* _tmp4_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (app != NULL, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = (BoxesSearchProvider*) g_object_new (object_type, NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = app;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (self->priv->app);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self->priv->app = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = g_str_hash;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = g_str_equal;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp4_ = g_hash_table_new_full (_tmp2_, _tmp3_, _g_free0_, _g_object_unref0_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_hash_table_unref0 (self->priv->boxes);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self->priv->boxes = _tmp4_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return self;
#line 539 "gnome-boxes-search-provider.c"
}


BoxesSearchProvider* boxes_search_provider_new (BoxesSearchProviderApp* app) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return boxes_search_provider_construct (BOXES_TYPE_SEARCH_PROVIDER, app);
#line 546 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_add_box (BoxesSearchProvider* self, BoxesBoxConfig* box) {
	gchar* id = NULL;
	guint _tmp0_ = 0U;
	gchar* _tmp1_ = NULL;
	BoxesBoxConfig* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GHashTable* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	BoxesBoxConfig* _tmp6_ = NULL;
	BoxesBoxConfig* _tmp7_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (box != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = self->priv->next_id;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self->priv->next_id = _tmp0_ + 1;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = g_strdup_printf ("%u", _tmp0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	id = _tmp1_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = box;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = g_strdup (id);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_set_data_full ((GObject*) _tmp2_, "search-id", _tmp3_, g_free);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp4_ = self->priv->boxes;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp5_ = g_strdup (id);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp6_ = box;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_hash_table_insert (_tmp4_, _tmp5_, _tmp7_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (id);
#line 590 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_load_data_free (gpointer _data) {
	BoxesSearchProviderLoadData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (BoxesSearchProviderLoadData, _data_);
#line 601 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_load (BoxesSearchProvider* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSearchProviderLoadData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (BoxesSearchProviderLoadData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_load);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_load_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_load_co (_data_);
#line 620 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_load_finish (BoxesSearchProvider* self, GAsyncResult* _res_) {
	BoxesSearchProviderLoadData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 628 "gnome-boxes-search-provider.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return _data1_;
#line 637 "gnome-boxes-search-provider.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 646 "gnome-boxes-search-provider.c"
		BoxesSearchProvider* self;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		self = _data1_->self;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_object_unref0 (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_slice_free (Block1Data, _data1_);
#line 654 "gnome-boxes-search-provider.c"
	}
}


static void ___lambda4_ (Block1Data* _data1_) {
	BoxesSearchProvider* self;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = _data1_->self;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_load_co (_data1_->_async_data_);
#line 665 "gnome-boxes-search-provider.c"
}


static void ____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	___lambda4_ (self);
#line 672 "gnome-boxes-search-provider.c"
}


static gboolean __lambda5_ (BoxesSearchProvider* self, const gchar* filename, GError** error) {
	gboolean result = FALSE;
	BoxesCollectionSource* source = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	gchar** _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = filename;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = boxes_collection_source_new_with_file (_tmp0_, &_inner_error_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	source = _tmp1_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_propagate_error (error, _inner_error_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return FALSE;
#line 700 "gnome-boxes-search-provider.c"
	}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = boxes_collection_source_get_enabled (source);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = _tmp2_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (!_tmp3_) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		result = FALSE;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_object_unref0 (source);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return result;
#line 714 "gnome-boxes-search-provider.c"
	}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp5_ = boxes_iconfig_get_groups ((BoxesIConfig*) source, "display", &_tmp4_);
#line 718 "gnome-boxes-search-provider.c"
	{
		gchar** group_collection = NULL;
		gint group_collection_length1 = 0;
		gint _group_collection_size_ = 0;
		gint group_it = 0;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		group_collection = _tmp5_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		group_collection_length1 = _tmp4_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		for (group_it = 0; group_it < _tmp4_; group_it = group_it + 1) {
#line 730 "gnome-boxes-search-provider.c"
			gchar* _tmp6_ = NULL;
			gchar* group = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_tmp6_ = g_strdup (group_collection[group_it]);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			group = _tmp6_;
#line 737 "gnome-boxes-search-provider.c"
			{
				BoxesBoxConfig* box = NULL;
				const gchar* _tmp7_ = NULL;
				BoxesBoxConfig* _tmp8_ = NULL;
				BoxesBoxConfig* _tmp9_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_tmp7_ = group;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_tmp8_ = boxes_box_config_new_with_group (source, _tmp7_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				box = _tmp8_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_tmp9_ = box;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				boxes_search_provider_add_box (self, _tmp9_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_object_unref0 (box);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (group);
#line 757 "gnome-boxes-search-provider.c"
			}
		}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		group_collection = (_vala_array_free (group_collection, group_collection_length1, (GDestroyNotify) g_free), NULL);
#line 762 "gnome-boxes-search-provider.c"
	}
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = FALSE;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (source);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 770 "gnome-boxes-search-provider.c"
}


static gboolean ___lambda5__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error) {
	gboolean result;
	result = __lambda5_ ((BoxesSearchProvider*) self, filename, error);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 779 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_load_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSearchProviderLoadData* _data_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_load_co (_data_);
#line 793 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_load_co (BoxesSearchProviderLoadData* _data_) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 802 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 806 "gnome-boxes-search-provider.c"
		goto _state_1;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 2:
#line 810 "gnome-boxes-search-provider.c"
		goto _state_2;
		default:
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 815 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_data1_ = g_slice_new0 (Block1Data);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_data1_->_ref_count_ = 1;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_data1_->self = g_object_ref (_data_->self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_data1_->_async_data_ = _data_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	while (TRUE) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp1_ = FALSE;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp1_ = _data_->self->priv->_loaded;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (!_data_->_tmp1_) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp2_ = FALSE;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp2_ = _data_->self->priv->loading;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp0_ = _data_->_tmp2_;
#line 840 "gnome-boxes-search-provider.c"
		} else {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp0_ = FALSE;
#line 844 "gnome-boxes-search-provider.c"
		}
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (!_data_->_tmp0_) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			break;
#line 850 "gnome-boxes-search-provider.c"
		}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp3_ = 0UL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp3_ = g_signal_connect_data ((GObject*) _data_->self, "notify::loaded", (GCallback) ____lambda4__g_object_notify, block1_data_ref (_data_->_data1_), (GClosureNotify) block1_data_unref, 0);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->wait = _data_->_tmp3_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_state_ = 1;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return FALSE;
#line 862 "gnome-boxes-search-provider.c"
		_state_1:
		;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp4_ = 0UL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp4_ = _data_->wait;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp4_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp5_ = FALSE;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_tmp5_ = _data_->self->priv->_loaded;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (_data_->_tmp5_) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			block1_data_unref (_data_->_data1_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_data1_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			if (_data_->_state_ == 0) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 885 "gnome-boxes-search-provider.c"
			} else {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 889 "gnome-boxes-search-provider.c"
			}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_object_unref (_data_->_async_result);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			return FALSE;
#line 895 "gnome-boxes-search-provider.c"
		}
	}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self->priv->loading = TRUE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6_ = boxes_get_user_pkgconfig_source (NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp7_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8_ = g_file_new_for_path (_data_->_tmp7_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp9_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_data_->_tmp7_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->dir = _data_->_tmp9_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10_ = _data_->dir;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_state_ = 2;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_foreach_filename_from_dir (_data_->_tmp10_, ___lambda5__boxes_foreach_filename_from_dir_func, _data_->self, boxes_search_provider_load_ready, _data_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 930 "gnome-boxes-search-provider.c"
	_state_2:
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_foreach_filename_from_dir_finish (_data_->_res_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_set_loaded (_data_->self, TRUE);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self->priv->loading = FALSE;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->dir);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	block1_data_unref (_data_->_data1_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_data1_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 948 "gnome-boxes-search-provider.c"
	} else {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 952 "gnome-boxes-search-provider.c"
	}
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 958 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_search_data_free (gpointer _data) {
	BoxesSearchProviderSearchData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = (_vala_array_free (_data_->terms, _data_->terms_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = (_vala_array_free (_data_->result, _data_->result_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (BoxesSearchProviderSearchData, _data_);
#line 973 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_search (BoxesSearchProvider* self, gchar** terms, int terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSearchProviderSearchData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (BoxesSearchProviderSearchData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_search);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_search_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = (_vala_array_free (_data_->terms, _data_->terms_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = terms;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms_length1 = terms_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_search_co (_data_);
#line 998 "gnome-boxes-search-provider.c"
}


static gchar** boxes_search_provider_search_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1) {
	gchar** result;
	BoxesSearchProviderSearchData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _data_->result;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	*result_length1 = _data_->result_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 1015 "gnome-boxes-search-provider.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		separator = "";
#line 1032 "gnome-boxes-search-provider.c"
	}
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 1042 "gnome-boxes-search-provider.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 1052 "gnome-boxes-search-provider.c"
	}
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 1058 "gnome-boxes-search-provider.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 1069 "gnome-boxes-search-provider.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 1081 "gnome-boxes-search-provider.c"
		} else {
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 1085 "gnome-boxes-search-provider.c"
		}
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 1089 "gnome-boxes-search-provider.c"
	}
#line 967 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1093 "gnome-boxes-search-provider.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 969 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 1116 "gnome-boxes-search-provider.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 1125 "gnome-boxes-search-provider.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 1138 "gnome-boxes-search-provider.c"
					gint _tmp10_ = 0;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 1144 "gnome-boxes-search-provider.c"
				}
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 1154 "gnome-boxes-search-provider.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 1166 "gnome-boxes-search-provider.c"
				} else {
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 1170 "gnome-boxes-search-provider.c"
				}
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 1176 "gnome-boxes-search-provider.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 1187 "gnome-boxes-search-provider.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 1202 "gnome-boxes-search-provider.c"
					} else {
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 1206 "gnome-boxes-search-provider.c"
					}
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 1210 "gnome-boxes-search-provider.c"
				}
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					break;
#line 1216 "gnome-boxes-search-provider.c"
				}
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 1228 "gnome-boxes-search-provider.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 1249 "gnome-boxes-search-provider.c"
				} else {
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 1253 "gnome-boxes-search-provider.c"
				}
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 1259 "gnome-boxes-search-provider.c"
			}
		}
#line 973 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 1266 "gnome-boxes-search-provider.c"
			gchar* _tmp32_ = NULL;
#line 974 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			return result;
#line 1274 "gnome-boxes-search-provider.c"
		}
#line 976 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 980 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 1312 "gnome-boxes-search-provider.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 1321 "gnome-boxes-search-provider.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 1337 "gnome-boxes-search-provider.c"
					gint _tmp47_ = 0;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 1343 "gnome-boxes-search-provider.c"
				}
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					break;
#line 1357 "gnome-boxes-search-provider.c"
				}
#line 982 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 982 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 1377 "gnome-boxes-search-provider.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 1392 "gnome-boxes-search-provider.c"
				} else {
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 1396 "gnome-boxes-search-provider.c"
				}
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 983 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 1404 "gnome-boxes-search-provider.c"
			}
		}
#line 986 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 986 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 986 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		return result;
#line 1415 "gnome-boxes-search-provider.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 988 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 988 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 988 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		return result;
#line 1424 "gnome-boxes-search-provider.c"
	}
}


static void boxes_search_provider_search_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSearchProviderSearchData* _data_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_search_co (_data_);
#line 1439 "gnome-boxes-search-provider.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	return _data2_;
#line 1448 "gnome-boxes-search-provider.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1457 "gnome-boxes-search-provider.c"
		GPtrArray* self;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		self = _data2_->self;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		_g_ptr_array_unref0 (self);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
		g_slice_free (Block2Data, _data2_);
#line 1465 "gnome-boxes-search-provider.c"
	}
}


static gint __lambda1_ (Block2Data* _data2_, gconstpointer** a, gconstpointer** b) {
	GPtrArray* self;
	gint result = 0;
	GCompareFunc _tmp0_ = NULL;
	gconstpointer** _tmp1_ = NULL;
	gconstpointer** _tmp2_ = NULL;
	gint _tmp3_ = 0;
#line 4427 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	self = _data2_->self;
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = _data2_->compare_func;
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp1_ = a;
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp2_ = b;
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3_ = _tmp0_ ((gconstpointer**) (*_tmp1_), (gconstpointer**) (*_tmp2_));
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	result = _tmp3_;
#line 4428 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 1491 "gnome-boxes-search-provider.c"
}


static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = __lambda1_ (self, a, b);
#line 4427 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 1500 "gnome-boxes-search-provider.c"
}


static void vala_g_ptr_array_sort (GPtrArray* self, GCompareFunc compare_func) {
	Block2Data* _data2_;
	GCompareFunc _tmp0_ = NULL;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_data2_ = g_slice_new0 (Block2Data);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_data2_->_ref_count_ = 1;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_data2_->self = g_ptr_array_ref (self);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = compare_func;
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_data2_->compare_func = _tmp0_;
#line 4427 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_ptr_array_sort_with_data (self, ___lambda1__gcompare_data_func, _data2_);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	block2_data_unref (_data2_);
#line 4426 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_data2_ = NULL;
#line 1525 "gnome-boxes-search-provider.c"
}


static gint __lambda6_ (BoxesBoxConfig* a, BoxesBoxConfig* b) {
	gint result = 0;
	BoxesBoxConfig* _tmp0_ = NULL;
	BoxesBoxConfig* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = a;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = b;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = boxes_box_config_compare (_tmp0_, _tmp1_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _tmp2_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 1548 "gnome-boxes-search-provider.c"
}


static gint ___lambda6__gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = __lambda6_ ((BoxesBoxConfig*) a, (BoxesBoxConfig*) b);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 1557 "gnome-boxes-search-provider.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 1572 "gnome-boxes-search-provider.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 1584 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_search_co (BoxesSearchProviderSearchData* _data_) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 1593 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 1597 "gnome-boxes-search-provider.c"
		goto _state_1;
		default:
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 1602 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = _data_->self->priv->app;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_hold ((GApplication*) _data_->_tmp0_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = _data_->terms;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = _data_->terms_length1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = _vala_g_strjoinv (" ", _data_->_tmp1_, _data_->_tmp1__length1);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = boxes_canonicalize_for_search (_data_->_tmp3_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp5_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp7_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp7_ = _data_->_tmp6_ = g_strsplit (_data_->_tmp5_, " ", 0);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8__length1 = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp8__length1 = _vala_array_length (_data_->_tmp6_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_data_->_tmp5_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_data_->_tmp3_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->normalized_terms_length1 = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_normalized_terms_size_ = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->normalized_terms = _data_->_tmp8_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->normalized_terms_length1 = _data_->_tmp8__length1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_normalized_terms_size_ = _data_->normalized_terms_length1;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp9_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp9_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->matches = _data_->_tmp9_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10__length1 = 0;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10_ = _data_->terms;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp10__length1 = _data_->terms_length1;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp11_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp11_ = _vala_g_strjoinv (", ", _data_->_tmp10_, _data_->_tmp10__length1);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp12_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_debug ("gnome-boxes-search-provider.vala:61: search (%s)", _data_->_tmp12_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_data_->_tmp12_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp13_ = FALSE;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp13_ = _data_->self->priv->_loaded;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (!_data_->_tmp13_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_state_ = 1;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		boxes_search_provider_load (_data_->self, boxes_search_provider_search_ready, _data_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return FALSE;
#line 1701 "gnome-boxes-search-provider.c"
		_state_1:
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		boxes_search_provider_load_finish (_data_->self, _data_->_res_);
#line 1705 "gnome-boxes-search-provider.c"
	}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp14_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp14_ = _data_->self->priv->boxes;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp15_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp15_ = g_hash_table_get_values (_data_->_tmp14_);
#line 1715 "gnome-boxes-search-provider.c"
	{
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->box_collection = _data_->_tmp15_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		for (_data_->box_it = _data_->box_collection; _data_->box_it != NULL; _data_->box_it = _data_->box_it->next) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->box = (BoxesBoxConfig*) _data_->box_it->data;
#line 1723 "gnome-boxes-search-provider.c"
			{
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16_ = _data_->box;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17__length1 = 0;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17_ = _data_->normalized_terms;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17__length1 = _data_->normalized_terms_length1;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp18_ = FALSE;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp18_ = boxes_box_config_contains_strings (_data_->_tmp16_, _data_->_tmp17_, _data_->_tmp17__length1);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (_data_->_tmp18_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp19_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp19_ = _data_->matches;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp20_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp20_ = _data_->box;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp21_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp21_ = _g_object_ref0 (_data_->_tmp20_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_ptr_array_add (_data_->_tmp19_, _data_->_tmp21_);
#line 1757 "gnome-boxes-search-provider.c"
				}
			}
		}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_list_free0 (_data_->box_collection);
#line 1763 "gnome-boxes-search-provider.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp22_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp22_ = _data_->matches;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	vala_g_ptr_array_sort (_data_->_tmp22_, ___lambda6__gcompare_func);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp23_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp23_ = _data_->matches;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp24_ = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp24_ = g_ptr_array_get_length (_data_->_tmp23_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp25_ = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp26_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp26_ = g_new0 (gchar*, _data_->_tmp25_ + 1);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->results_length1 = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_results_size_ = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->results = _data_->_tmp26_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->results_length1 = _data_->_tmp25_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_results_size_ = _data_->results_length1;
#line 1797 "gnome-boxes-search-provider.c"
	{
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->i = 0;
#line 1801 "gnome-boxes-search-provider.c"
		{
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp27_ = TRUE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			while (TRUE) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (!_data_->_tmp27_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp28_ = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp28_ = _data_->i;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->i = _data_->_tmp28_ + 1;
#line 1815 "gnome-boxes-search-provider.c"
				}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp27_ = FALSE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp29_ = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp29_ = _data_->i;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp30_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp30_ = _data_->matches;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp31_ = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp31_ = g_ptr_array_get_length (_data_->_tmp30_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp32_ = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp32_ = _data_->_tmp31_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (!(_data_->_tmp29_ < _data_->_tmp32_)) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					break;
#line 1839 "gnome-boxes-search-provider.c"
				}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33__length1 = 0;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33_ = _data_->results;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33__length1 = _data_->results_length1;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp34_ = 0;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp34_ = _data_->i;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp35_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp35_ = _data_->matches;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp36_ = 0;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp36_ = _data_->i;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp37_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp37_ = g_ptr_array_index (_data_->_tmp35_, (guint) _data_->_tmp36_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp38_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp38_ = g_object_get_data ((GObject*) ((BoxesBoxConfig*) _data_->_tmp37_), "search-id");
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp39_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp39_ = g_strdup ((const gchar*) _data_->_tmp38_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (_data_->_tmp33_[_data_->_tmp34_]);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33_[_data_->_tmp34_] = _data_->_tmp39_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp40_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp40_ = _data_->_tmp33_[_data_->_tmp34_];
#line 1881 "gnome-boxes-search-provider.c"
			}
		}
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp41_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp41_ = _data_->self->priv->app;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_release ((GApplication*) _data_->_tmp41_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp42_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp42__length1 = 0;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp42_ = _data_->results;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp42__length1 = _data_->results_length1;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result_length1 = _data_->_tmp42__length1;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = _data_->_tmp42_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_ptr_array_unref0 (_data_->matches);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->normalized_terms = (_vala_array_free (_data_->normalized_terms, _data_->normalized_terms_length1, (GDestroyNotify) g_free), NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = (_vala_array_free (_data_->terms, _data_->terms_length1, (GDestroyNotify) g_free), NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1913 "gnome-boxes-search-provider.c"
	} else {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1917 "gnome-boxes-search-provider.c"
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->results = (_vala_array_free (_data_->results, _data_->results_length1, (GDestroyNotify) g_free), NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_ptr_array_unref0 (_data_->matches);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->normalized_terms = (_vala_array_free (_data_->normalized_terms, _data_->normalized_terms_length1, (GDestroyNotify) g_free), NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = (_vala_array_free (_data_->terms, _data_->terms_length1, (GDestroyNotify) g_free), NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1935 "gnome-boxes-search-provider.c"
	} else {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1939 "gnome-boxes-search-provider.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 1945 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetInitialResultSet_data_free (gpointer _data) {
	boxes_search_provider_GetInitialResultSetData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = (_vala_array_free (_data_->result, _data_->result_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (boxes_search_provider_GetInitialResultSetData, _data_);
#line 1958 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_GetInitialResultSet (BoxesSearchProvider* self, gchar** terms, int terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	boxes_search_provider_GetInitialResultSetData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (boxes_search_provider_GetInitialResultSetData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_GetInitialResultSet);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_GetInitialResultSet_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = terms;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1__length1 = terms_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms = _tmp1_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->terms_length1 = _tmp1__length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetInitialResultSet_co (_data_);
#line 1987 "gnome-boxes-search-provider.c"
}


gchar** boxes_search_provider_GetInitialResultSet_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1) {
	gchar** result;
	boxes_search_provider_GetInitialResultSetData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _data_->result;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	*result_length1 = _data_->result_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2004 "gnome-boxes-search-provider.c"
}


static gchar** _vala_array_dup1 (gchar** self, int length) {
	gchar** result;
	int i;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = g_new0 (gchar*, length + 1);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	for (i = 0; i < length; i++) {
#line 2015 "gnome-boxes-search-provider.c"
		gchar* _tmp0_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp0_ = g_strdup (self[i]);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		result[i] = _tmp0_;
#line 2021 "gnome-boxes-search-provider.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2025 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetInitialResultSet_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	boxes_search_provider_GetInitialResultSetData* _data_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetInitialResultSet_co (_data_);
#line 2039 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_GetInitialResultSet_co (boxes_search_provider_GetInitialResultSetData* _data_) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 2048 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 2052 "gnome-boxes-search-provider.c"
		goto _state_1;
		default:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 2057 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = 0;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = _data_->terms;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = _data_->terms_length1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = 0;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = (_data_->_tmp0_ != NULL) ? _vala_array_dup1 (_data_->_tmp0_, _data_->_tmp0__length1) : ((gpointer) _data_->_tmp0_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = _data_->_tmp0__length1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = 0;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_state_ = 1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_search (_data_->self, _data_->_tmp1_, _data_->_tmp1__length1, boxes_search_provider_GetInitialResultSet_ready, _data_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 2084 "gnome-boxes-search-provider.c"
	_state_1:
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = boxes_search_provider_search_finish (_data_->self, _data_->_res_, &_data_->_tmp2_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = 0;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = _data_->_tmp2_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result_length1 = _data_->_tmp4__length1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = _data_->_tmp4_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2106 "gnome-boxes-search-provider.c"
	} else {
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2110 "gnome-boxes-search-provider.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2120 "gnome-boxes-search-provider.c"
	} else {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2124 "gnome-boxes-search-provider.c"
	}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 2130 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetSubsearchResultSet_data_free (gpointer _data) {
	boxes_search_provider_GetSubsearchResultSetData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = (_vala_array_free (_data_->result, _data_->result_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (boxes_search_provider_GetSubsearchResultSetData, _data_);
#line 2143 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_GetSubsearchResultSet (BoxesSearchProvider* self, gchar** previous_results, int previous_results_length1, gchar** new_terms, int new_terms_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	boxes_search_provider_GetSubsearchResultSetData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (boxes_search_provider_GetSubsearchResultSetData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_GetSubsearchResultSet);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_GetSubsearchResultSet_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = previous_results;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1__length1 = previous_results_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->previous_results = _tmp1_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->previous_results_length1 = _tmp1__length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = new_terms;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2__length1 = new_terms_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->new_terms = _tmp2_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->new_terms_length1 = _tmp2__length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetSubsearchResultSet_co (_data_);
#line 2182 "gnome-boxes-search-provider.c"
}


gchar** boxes_search_provider_GetSubsearchResultSet_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1) {
	gchar** result;
	boxes_search_provider_GetSubsearchResultSetData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _data_->result;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	*result_length1 = _data_->result_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2199 "gnome-boxes-search-provider.c"
}


static gchar** _vala_array_dup2 (gchar** self, int length) {
	gchar** result;
	int i;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = g_new0 (gchar*, length + 1);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	for (i = 0; i < length; i++) {
#line 2210 "gnome-boxes-search-provider.c"
		gchar* _tmp0_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp0_ = g_strdup (self[i]);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		result[i] = _tmp0_;
#line 2216 "gnome-boxes-search-provider.c"
	}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2220 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetSubsearchResultSet_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	boxes_search_provider_GetSubsearchResultSetData* _data_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetSubsearchResultSet_co (_data_);
#line 2234 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_GetSubsearchResultSet_co (boxes_search_provider_GetSubsearchResultSetData* _data_) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 2243 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 2247 "gnome-boxes-search-provider.c"
		goto _state_1;
		default:
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 2252 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = _data_->new_terms;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = _data_->new_terms_length1;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = (_data_->_tmp0_ != NULL) ? _vala_array_dup2 (_data_->_tmp0_, _data_->_tmp0__length1) : ((gpointer) _data_->_tmp0_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = _data_->_tmp0__length1;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_state_ = 1;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_search (_data_->self, _data_->_tmp1_, _data_->_tmp1__length1, boxes_search_provider_GetSubsearchResultSet_ready, _data_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 2279 "gnome-boxes-search-provider.c"
	_state_1:
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = boxes_search_provider_search_finish (_data_->self, _data_->_res_, &_data_->_tmp2_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = _data_->_tmp2_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result_length1 = _data_->_tmp4__length1;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = _data_->_tmp4_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2301 "gnome-boxes-search-provider.c"
	} else {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2305 "gnome-boxes-search-provider.c"
	}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2315 "gnome-boxes-search-provider.c"
	} else {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2319 "gnome-boxes-search-provider.c"
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 2325 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_get_metas_data_free (gpointer _data) {
	BoxesSearchProviderGetMetasData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = (_vala_array_free (_data_->ids, _data_->ids_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = (_vala_array_free (_data_->result, _data_->result_length1, (GDestroyNotify) g_hash_table_unref), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (BoxesSearchProviderGetMetasData, _data_);
#line 2340 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_get_metas (BoxesSearchProvider* self, gchar** ids, int ids_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSearchProviderGetMetasData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (BoxesSearchProviderGetMetasData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_get_metas);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_get_metas_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = (_vala_array_free (_data_->ids, _data_->ids_length1, (GDestroyNotify) g_free), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = ids;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids_length1 = ids_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_get_metas_co (_data_);
#line 2365 "gnome-boxes-search-provider.c"
}


GHashTable** boxes_search_provider_get_metas_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1) {
	GHashTable** result;
	BoxesSearchProviderGetMetasData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _data_->result;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	*result_length1 = _data_->result_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2382 "gnome-boxes-search-provider.c"
}


static void _g_variant_unref0_ (gpointer var) {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(var == NULL) ? NULL : (var = (g_variant_unref (var), NULL));
#line 2389 "gnome-boxes-search-provider.c"
}


static gpointer _g_hash_table_ref0 (gpointer self) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return self ? g_hash_table_ref (self) : NULL;
#line 2396 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_get_metas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSearchProviderGetMetasData* _data_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_get_metas_co (_data_);
#line 2410 "gnome-boxes-search-provider.c"
}


static GHashTable** _vala_array_dup3 (GHashTable** self, int length) {
	GHashTable** result;
	int i;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = g_new0 (GHashTable*, length + 1);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	for (i = 0; i < length; i++) {
#line 2421 "gnome-boxes-search-provider.c"
		GHashTable* _tmp0_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp0_ = _g_hash_table_ref0 (self[i]);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		result[i] = _tmp0_;
#line 2427 "gnome-boxes-search-provider.c"
	}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 2431 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_get_metas_co (BoxesSearchProviderGetMetasData* _data_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 2440 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 2444 "gnome-boxes-search-provider.c"
		goto _state_1;
		default:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 2449 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = 0;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = _data_->ids;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = _data_->ids_length1;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = g_new0 (GHashTable*, _data_->_tmp0__length1 + 1);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->metas_length1 = 0;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_metas_size_ = 0;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->metas = _data_->_tmp1_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->metas_length1 = _data_->_tmp0__length1;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_metas_size_ = _data_->metas_length1;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = _data_->self->priv->app;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_hold ((GApplication*) _data_->_tmp2_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3__length1 = 0;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = _data_->ids;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3__length1 = _data_->ids_length1;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = _vala_g_strjoinv (", ", _data_->_tmp3_, _data_->_tmp3__length1);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp5_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_debug ("gnome-boxes-search-provider.vala:92: GetResultMetas (%s)", _data_->_tmp5_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_data_->_tmp5_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->n = (guint) 0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6__length1 = 0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6_ = _data_->ids;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp6__length1 = _data_->ids_length1;
#line 2510 "gnome-boxes-search-provider.c"
	{
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->id_collection_length1 = 0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->_id_collection_size_ = 0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->id_collection = _data_->_tmp6_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_data_->id_collection_length1 = _data_->_tmp6__length1;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		for (_data_->id_it = 0; _data_->id_it < _data_->_tmp6__length1; _data_->id_it = _data_->id_it + 1) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp7_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->_tmp7_ = g_strdup (_data_->id_collection[_data_->id_it]);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_data_->id = _data_->_tmp7_;
#line 2528 "gnome-boxes-search-provider.c"
			{
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp8_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp8_ = _data_->self->priv->boxes;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp9_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp9_ = _data_->id;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp10_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp10_ = g_hash_table_lookup (_data_->_tmp8_, _data_->_tmp9_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp11_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp11_ = _g_object_ref0 ((BoxesBoxConfig*) _data_->_tmp10_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->box = _data_->_tmp11_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp12_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp12_ = _data_->box;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (_data_->_tmp12_ == NULL) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->box);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_free0 (_data_->id);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					continue;
#line 2560 "gnome-boxes-search-provider.c"
				}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp13_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp13_ = g_str_hash;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp14_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp14_ = g_str_equal;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp15_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp15_ = g_hash_table_new_full (_data_->_tmp13_, _data_->_tmp14_, _g_free0_, _g_variant_unref0_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->meta = _data_->_tmp15_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16__length1 = 0;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16_ = _data_->metas;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16__length1 = _data_->metas_length1;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17_ = 0U;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp17_ = _data_->n;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp18_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp18_ = _data_->meta;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp19_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp19_ = _g_hash_table_ref0 (_data_->_tmp18_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_hash_table_unref0 (_data_->_tmp16_[_data_->_tmp17_]);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp16_[_data_->_tmp17_] = _data_->_tmp19_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp20_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp20_ = _data_->_tmp16_[_data_->_tmp17_];
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp21_ = 0U;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp21_ = _data_->n;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->n = _data_->_tmp21_ + 1;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp22_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp22_ = _data_->meta;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp23_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp23_ = g_strdup ("id");
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp24_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp24_ = _data_->id;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp25_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp25_ = g_variant_new_string (_data_->_tmp24_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_variant_ref_sink (_data_->_tmp25_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_hash_table_insert (_data_->_tmp22_, _data_->_tmp23_, _data_->_tmp25_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp26_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp26_ = _data_->meta;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp27_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp27_ = g_strdup ("name");
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp28_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp28_ = _data_->box;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp29_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp29_ = boxes_box_config_get_last_seen_name (_data_->_tmp28_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp30_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp31_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp31_ = _data_->_tmp30_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp32_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp32_ = g_variant_new_string (_data_->_tmp31_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_variant_ref_sink (_data_->_tmp32_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				g_hash_table_insert (_data_->_tmp26_, _data_->_tmp27_, _data_->_tmp32_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (_data_->_tmp31_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp33_ = _data_->box;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp34_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp34_ = boxes_box_config_get_uuid (_data_->_tmp33_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp35_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp35_ = _data_->_tmp34_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp36_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp36_ = _data_->_tmp35_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp37_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp37_ = boxes_get_screenshot_filename (_data_->_tmp36_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp38_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp38_ = _data_->_tmp37_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp39_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp39_ = g_file_new_for_path (_data_->_tmp38_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp40_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp40_ = _data_->_tmp39_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (_data_->_tmp38_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (_data_->_tmp36_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->file = _data_->_tmp40_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->info = NULL;
#line 2704 "gnome-boxes-search-provider.c"
				{
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp42_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp42_ = _data_->file;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_state_ = 1;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_file_query_info_async (_data_->_tmp42_, G_FILE_ATTRIBUTE_STANDARD_TYPE, G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT, NULL, boxes_search_provider_get_metas_ready, _data_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					return FALSE;
#line 2716 "gnome-boxes-search-provider.c"
					_state_1:
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp43_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp43_ = g_file_query_info_finish (_data_->_tmp42_, _data_->_res_, &_data_->_inner_error_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp41_ = _data_->_tmp43_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2726 "gnome-boxes-search-provider.c"
						goto __catch0_g_error;
					}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp44_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp44_ = _data_->_tmp41_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp41_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->info);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->info = _data_->_tmp44_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->_tmp41_);
#line 2741 "gnome-boxes-search-provider.c"
				}
				goto __finally0;
				__catch0_g_error:
				{
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_inner_error_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_error_free0 (_data_->_error_);
#line 2752 "gnome-boxes-search-provider.c"
				}
				__finally0:
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->info);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->file);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_hash_table_unref0 (_data_->meta);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->box);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_free0 (_data_->id);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->metas = (_vala_array_free (_data_->metas, _data_->metas_length1, (GDestroyNotify) g_hash_table_unref), NULL);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->ids = (_vala_array_free (_data_->ids, _data_->ids_length1, (GDestroyNotify) g_free), NULL);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_clear_error (&_data_->_inner_error_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					return FALSE;
#line 2777 "gnome-boxes-search-provider.c"
				}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp45_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_data_->_tmp45_ = _data_->info;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				if (_data_->_tmp45_ != NULL) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp46_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp46_ = _data_->file;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp47_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp47_ = (GFileIcon*) g_file_icon_new (_data_->_tmp46_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->icon = _data_->_tmp47_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp48_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp48_ = _data_->meta;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp49_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp49_ = g_strdup ("gicon");
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp50_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp50_ = _data_->icon;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp51_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp51_ = g_icon_to_string ((GIcon*) _data_->_tmp50_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp52_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp52_ = _data_->_tmp51_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp53_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp53_ = g_variant_new_string (_data_->_tmp52_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_variant_ref_sink (_data_->_tmp53_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_hash_table_insert (_data_->_tmp48_, _data_->_tmp49_, _data_->_tmp53_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_free0 (_data_->_tmp52_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->icon);
#line 2827 "gnome-boxes-search-provider.c"
				} else {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp54_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp54_ = _data_->meta;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp55_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp55_ = g_strdup ("gicon");
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp56_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp56_ = (GThemedIcon*) g_themed_icon_new ("gnome-boxes");
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp57_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp57_ = _data_->_tmp56_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp58_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp58_ = g_icon_to_string ((GIcon*) _data_->_tmp57_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp59_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp59_ = _data_->_tmp58_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp60_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_data_->_tmp60_ = g_variant_new_string (_data_->_tmp59_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_variant_ref_sink (_data_->_tmp60_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					g_hash_table_insert (_data_->_tmp54_, _data_->_tmp55_, _data_->_tmp60_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_free0 (_data_->_tmp59_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_object_unref0 (_data_->_tmp57_);
#line 2865 "gnome-boxes-search-provider.c"
				}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_object_unref0 (_data_->info);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_object_unref0 (_data_->file);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_hash_table_unref0 (_data_->meta);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_object_unref0 (_data_->box);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_g_free0 (_data_->id);
#line 2877 "gnome-boxes-search-provider.c"
			}
		}
	}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp61_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp61_ = _data_->self->priv->app;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_release ((GApplication*) _data_->_tmp61_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp62_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp62__length1 = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp62_ = _data_->metas;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp62__length1 = _data_->metas_length1;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp63_ = 0U;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp63_ = _data_->n;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp64_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp64__length1 = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp64_ = ((_data_->_tmp62_ + 0) != NULL) ? _vala_array_dup3 (_data_->_tmp62_ + 0, ((gint) _data_->_tmp63_) - 0) : ((gpointer) (_data_->_tmp62_ + 0));
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp64__length1 = ((gint) _data_->_tmp63_) - 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp65_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp65__length1 = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp65_ = _data_->_tmp64_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp65__length1 = _data_->_tmp64__length1;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result_length1 = _data_->_tmp65__length1;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = _data_->_tmp65_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->metas = (_vala_array_free (_data_->metas, _data_->metas_length1, (GDestroyNotify) g_hash_table_unref), NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = (_vala_array_free (_data_->ids, _data_->ids_length1, (GDestroyNotify) g_free), NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2927 "gnome-boxes-search-provider.c"
	} else {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2931 "gnome-boxes-search-provider.c"
	}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->metas = (_vala_array_free (_data_->metas, _data_->metas_length1, (GDestroyNotify) g_hash_table_unref), NULL);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = (_vala_array_free (_data_->ids, _data_->ids_length1, (GDestroyNotify) g_free), NULL);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2945 "gnome-boxes-search-provider.c"
	} else {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2949 "gnome-boxes-search-provider.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 2955 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetResultMetas_data_free (gpointer _data) {
	boxes_search_provider_GetResultMetasData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = (_vala_array_free (_data_->result, _data_->result_length1, (GDestroyNotify) g_hash_table_unref), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_slice_free (boxes_search_provider_GetResultMetasData, _data_);
#line 2968 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_GetResultMetas (BoxesSearchProvider* self, gchar** ids, int ids_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	boxes_search_provider_GetResultMetasData* _data_;
	BoxesSearchProvider* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_slice_new0 (boxes_search_provider_GetResultMetasData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_search_provider_GetResultMetas);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_search_provider_GetResultMetas_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = ids;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1__length1 = ids_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids = _tmp1_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->ids_length1 = _tmp1__length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetResultMetas_co (_data_);
#line 2997 "gnome-boxes-search-provider.c"
}


GHashTable** boxes_search_provider_GetResultMetas_finish (BoxesSearchProvider* self, GAsyncResult* _res_, int* result_length1) {
	GHashTable** result;
	boxes_search_provider_GetResultMetasData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _data_->result;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	*result_length1 = _data_->result_length1;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 3014 "gnome-boxes-search-provider.c"
}


static gchar** _vala_array_dup4 (gchar** self, int length) {
	gchar** result;
	int i;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = g_new0 (gchar*, length + 1);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	for (i = 0; i < length; i++) {
#line 3025 "gnome-boxes-search-provider.c"
		gchar* _tmp0_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp0_ = g_strdup (self[i]);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		result[i] = _tmp0_;
#line 3031 "gnome-boxes-search-provider.c"
	}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 3035 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_GetResultMetas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	boxes_search_provider_GetResultMetasData* _data_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_ = _user_data_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_source_object_ = source_object;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_res_ = _res_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_GetResultMetas_co (_data_);
#line 3049 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_GetResultMetas_co (boxes_search_provider_GetResultMetasData* _data_) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (_data_->_state_) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 0:
#line 3058 "gnome-boxes-search-provider.c"
		goto _state_0;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case 1:
#line 3062 "gnome-boxes-search-provider.c"
		goto _state_1;
		default:
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_assert_not_reached ();
#line 3067 "gnome-boxes-search-provider.c"
	}
	_state_0:
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0_ = _data_->ids;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp0__length1 = _data_->ids_length1;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1_ = (_data_->_tmp0_ != NULL) ? _vala_array_dup4 (_data_->_tmp0_, _data_->_tmp0__length1) : ((gpointer) _data_->_tmp0_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp1__length1 = _data_->_tmp0__length1;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp2_ = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_state_ = 1;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_get_metas (_data_->self, _data_->_tmp1_, _data_->_tmp1__length1, boxes_search_provider_GetResultMetas_ready, _data_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 3094 "gnome-boxes-search-provider.c"
	_state_1:
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp3_ = boxes_search_provider_get_metas_finish (_data_->self, _data_->_res_, &_data_->_tmp2_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->_tmp4__length1 = _data_->_tmp2_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result_length1 = _data_->_tmp4__length1;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_data_->result = _data_->_tmp4_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3116 "gnome-boxes-search-provider.c"
	} else {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3120 "gnome-boxes-search-provider.c"
	}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_data_->_state_ == 0) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3130 "gnome-boxes-search-provider.c"
	} else {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3134 "gnome-boxes-search-provider.c"
	}
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_unref (_data_->_async_result);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return FALSE;
#line 3140 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_ActivateResult (BoxesSearchProvider* self, const gchar* search_id, gchar** terms, int terms_length1, guint32 timestamp) {
	BoxesSearchProviderApp* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesBoxConfig* box = NULL;
	GHashTable* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gconstpointer _tmp4_ = NULL;
	BoxesBoxConfig* _tmp5_ = NULL;
	BoxesBoxConfig* _tmp6_ = NULL;
	gchar* uuid = NULL;
	BoxesBoxConfig* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	BoxesSearchProviderApp* _tmp25_ = NULL;
	GError * _inner_error_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (self != NULL);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (search_id != NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = self->priv->app;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_hold ((GApplication*) _tmp0_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = search_id;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_debug ("gnome-boxes-search-provider.vala:133: ActivateResult (%s)", _tmp1_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = self->priv->boxes;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = search_id;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp4_ = g_hash_table_lookup (_tmp2_, _tmp3_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp5_ = _g_object_ref0 ((BoxesBoxConfig*) _tmp4_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	box = _tmp5_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp6_ = box;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_tmp6_ == NULL) {
#line 3185 "gnome-boxes-search-provider.c"
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		BoxesSearchProviderApp* _tmp10_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp7_ = search_id;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp8_ = g_strconcat ("Can't find id: ", _tmp7_, NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp9_ = _tmp8_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_warning ("gnome-boxes-search-provider.vala:137: %s", _tmp9_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_free0 (_tmp9_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp10_ = self->priv->app;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_application_release ((GApplication*) _tmp10_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_object_unref0 (box);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return;
#line 3208 "gnome-boxes-search-provider.c"
	}
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp11_ = box;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp12_ = boxes_box_config_get_uuid (_tmp11_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp13_ = _tmp12_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	uuid = _tmp13_;
#line 3218 "gnome-boxes-search-provider.c"
	{
		gchar* cmd = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
		const gchar* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp14_ = uuid;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp15_ = g_strconcat ("gnome-boxes --open-uuid ", _tmp14_, NULL);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		cmd = _tmp15_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp17_ = cmd;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp18_ = g_spawn_command_line_async (_tmp17_, &_inner_error_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp16_ = _tmp18_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_g_free0 (cmd);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			if (_inner_error_->domain == G_SPAWN_ERROR) {
#line 3244 "gnome-boxes-search-provider.c"
				goto __catch1_g_spawn_error;
			}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_g_free0 (cmd);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_g_free0 (uuid);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_g_object_unref0 (box);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_clear_error (&_inner_error_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			return;
#line 3259 "gnome-boxes-search-provider.c"
		}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (!_tmp16_) {
#line 3263 "gnome-boxes-search-provider.c"
			FILE* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_tmp19_ = stderr;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_tmp20_ = uuid;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			fprintf (_tmp19_, "Failed to launch Boxes with uuid '%s'\n", _tmp20_);
#line 3272 "gnome-boxes-search-provider.c"
		}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_free0 (cmd);
#line 3276 "gnome-boxes-search-provider.c"
	}
	goto __finally1;
	__catch1_g_spawn_error:
	{
		GError* _error_ = NULL;
		FILE* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GError* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_error_ = _inner_error_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_inner_error_ = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp21_ = stderr;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp22_ = uuid;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		fprintf (_tmp21_, "Failed to launch Boxes with uuid '%s'\n", _tmp22_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp23_ = _error_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp24_ = _tmp23_->message;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_warning ("gnome-boxes-search-provider.vala:149: %s", _tmp24_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_error_free0 (_error_);
#line 3304 "gnome-boxes-search-provider.c"
	}
	__finally1:
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_free0 (uuid);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_object_unref0 (box);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_clear_error (&_inner_error_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return;
#line 3319 "gnome-boxes-search-provider.c"
	}
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp25_ = self->priv->app;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_release ((GApplication*) _tmp25_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (uuid);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (box);
#line 3329 "gnome-boxes-search-provider.c"
}


static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if ((*length) == (*size)) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3340 "gnome-boxes-search-provider.c"
	}
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[(*length)++] = value;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[*length] = NULL;
#line 3346 "gnome-boxes-search-provider.c"
}


static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value) {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if ((*length) == (*size)) {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3357 "gnome-boxes-search-provider.c"
	}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[(*length)++] = value;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[*length] = NULL;
#line 3363 "gnome-boxes-search-provider.c"
}


static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if ((*length) == (*size)) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3374 "gnome-boxes-search-provider.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[(*length)++] = value;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	(*array)[*length] = NULL;
#line 3380 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_LaunchSearch (BoxesSearchProvider* self, gchar** terms, int terms_length1, guint32 timestamp) {
	BoxesSearchProviderApp* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	BoxesSearchProviderApp* _tmp21_ = NULL;
	GError * _inner_error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (self != NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = self->priv->app;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_hold ((GApplication*) _tmp0_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = terms;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1__length1 = terms_length1;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = _vala_g_strjoinv (", ", _tmp1_, _tmp1__length1);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = _tmp2_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_debug ("gnome-boxes-search-provider.vala:158: LaunchSearch (%s)", _tmp3_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_free0 (_tmp3_);
#line 3410 "gnome-boxes-search-provider.c"
	{
		gchar** args = NULL;
		gchar** _tmp4_ = NULL;
		gint args_length1 = 0;
		gint _args_size_ = 0;
		gchar** _tmp5_ = NULL;
		gint _tmp5__length1 = 0;
		gchar* _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		gint _tmp7__length1 = 0;
		gboolean _tmp14_ = FALSE;
		gchar** _tmp15_ = NULL;
		gint _tmp15__length1 = 0;
		gboolean _tmp16_ = FALSE;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp4_ = g_new0 (gchar*, 0 + 1);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		args = _tmp4_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		args_length1 = 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_args_size_ = args_length1;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp5_ = args;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp5__length1 = args_length1;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp6_ = g_strdup ("gnome-boxes");
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_vala_array_add1 (&args, &args_length1, &_args_size_, _tmp6_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp7_ = terms;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp7__length1 = terms_length1;
#line 3445 "gnome-boxes-search-provider.c"
		{
			gchar** term_collection = NULL;
			gint term_collection_length1 = 0;
			gint _term_collection_size_ = 0;
			gint term_it = 0;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			term_collection = _tmp7_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			term_collection_length1 = _tmp7__length1;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			for (term_it = 0; term_it < _tmp7__length1; term_it = term_it + 1) {
#line 3457 "gnome-boxes-search-provider.c"
				gchar* _tmp8_ = NULL;
				gchar* term = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				_tmp8_ = g_strdup (term_collection[term_it]);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
				term = _tmp8_;
#line 3464 "gnome-boxes-search-provider.c"
				{
					gchar** _tmp9_ = NULL;
					gint _tmp9__length1 = 0;
					gchar* _tmp10_ = NULL;
					gchar** _tmp11_ = NULL;
					gint _tmp11__length1 = 0;
					const gchar* _tmp12_ = NULL;
					gchar* _tmp13_ = NULL;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp9_ = args;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp9__length1 = args_length1;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp10_ = g_strdup ("--search");
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_vala_array_add2 (&args, &args_length1, &_args_size_, _tmp10_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp11_ = args;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp11__length1 = args_length1;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp12_ = term;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_tmp13_ = g_strdup (_tmp12_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_vala_array_add3 (&args, &args_length1, &_args_size_, _tmp13_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
					_g_free0 (term);
#line 3493 "gnome-boxes-search-provider.c"
				}
			}
		}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp15_ = args;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp15__length1 = args_length1;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp16_ = g_spawn_async (NULL, _tmp15_, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &_inner_error_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp14_ = _tmp16_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			if (_inner_error_->domain == G_SPAWN_ERROR) {
#line 3511 "gnome-boxes-search-provider.c"
				goto __catch2_g_spawn_error;
			}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_clear_error (&_inner_error_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			return;
#line 3522 "gnome-boxes-search-provider.c"
		}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (!_tmp14_) {
#line 3526 "gnome-boxes-search-provider.c"
			FILE* _tmp17_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			_tmp17_ = stderr;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			fprintf (_tmp17_, "Failed to launch Boxes for search\n");
#line 3532 "gnome-boxes-search-provider.c"
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 3536 "gnome-boxes-search-provider.c"
	}
	goto __finally2;
	__catch2_g_spawn_error:
	{
		GError* _error_ = NULL;
		FILE* _tmp18_ = NULL;
		GError* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_error_ = _inner_error_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_inner_error_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp18_ = stderr;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		fprintf (_tmp18_, "Failed to launch Boxes for search\n");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp19_ = _error_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp20_ = _tmp19_->message;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_warning ("gnome-boxes-search-provider.vala:171: %s", _tmp20_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_error_free0 (_error_);
#line 3561 "gnome-boxes-search-provider.c"
	}
	__finally2:
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_clear_error (&_inner_error_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return;
#line 3572 "gnome-boxes-search-provider.c"
	}
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp21_ = self->priv->app;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_application_release ((GApplication*) _tmp21_);
#line 3578 "gnome-boxes-search-provider.c"
}


gboolean boxes_search_provider_get_loaded (BoxesSearchProvider* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = self->priv->_loaded;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 3593 "gnome-boxes-search-provider.c"
}


void boxes_search_provider_set_loaded (BoxesSearchProvider* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self->priv->_loaded = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_notify ((GObject *) self, "loaded");
#line 3607 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_class_init (BoxesSearchProviderClass * klass) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_type_class_add_private (klass, sizeof (BoxesSearchProviderPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_search_provider_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_search_provider_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_search_provider_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCH_PROVIDER_LOADED, g_param_spec_boolean ("loaded", "loaded", "loaded", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3624 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_instance_init (BoxesSearchProvider * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self->priv = BOXES_SEARCH_PROVIDER_GET_PRIVATE (self);
#line 3631 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_finalize (GObject* obj) {
	BoxesSearchProvider * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProvider);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (self->priv->app);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_hash_table_unref0 (self->priv->boxes);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	G_OBJECT_CLASS (boxes_search_provider_parent_class)->finalize (obj);
#line 3645 "gnome-boxes-search-provider.c"
}


GType boxes_search_provider_get_type (void) {
	static volatile gsize boxes_search_provider_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_search_provider_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSearchProviderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_search_provider_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSearchProvider), 0, (GInstanceInitFunc) boxes_search_provider_instance_init, NULL };
		GType boxes_search_provider_type_id;
		boxes_search_provider_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesSearchProvider", &g_define_type_info, 0);
		g_type_set_qdata (boxes_search_provider_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_search_provider_register_object);
		g_once_init_leave (&boxes_search_provider_type_id__volatile, boxes_search_provider_type_id);
	}
	return boxes_search_provider_type_id__volatile;
}


static void _vala_boxes_search_provider_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSearchProvider * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProvider);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case BOXES_SEARCH_PROVIDER_LOADED:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_value_set_boolean (value, boxes_search_provider_get_loaded (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		break;
#line 3673 "gnome-boxes-search-provider.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		break;
#line 3679 "gnome-boxes-search-provider.c"
	}
}


static void _vala_boxes_search_provider_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSearchProvider * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCH_PROVIDER, BoxesSearchProvider);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		case BOXES_SEARCH_PROVIDER_LOADED:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		boxes_search_provider_set_loaded (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		break;
#line 3695 "gnome-boxes-search-provider.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		break;
#line 3701 "gnome-boxes-search-provider.c"
	}
}


static void _dbus_boxes_search_provider_GetInitialResultSet (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	gchar** terms = NULL;
	int terms_length1 = 0;
	GVariant* _tmp0_;
	gchar** _tmp1_;
	int _tmp1__length;
	int _tmp1__size;
	int _tmp1__length1;
	GVariantIter _tmp2_;
	GVariant* _tmp3_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp0_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp1_ = g_new (gchar*, 5);
	_tmp1__length = 0;
	_tmp1__size = 4;
	_tmp1__length1 = 0;
	g_variant_iter_init (&_tmp2_, _tmp0_);
	for (; (_tmp3_ = g_variant_iter_next_value (&_tmp2_)) != NULL; _tmp1__length1++) {
		if (_tmp1__size == _tmp1__length) {
			_tmp1__size = 2 * _tmp1__size;
			_tmp1_ = g_renew (gchar*, _tmp1_, _tmp1__size + 1);
		}
		_tmp1_[_tmp1__length++] = g_variant_dup_string (_tmp3_, NULL);
		g_variant_unref (_tmp3_);
	}
	terms_length1 = _tmp1__length1;
	_tmp1_[_tmp1__length] = NULL;
	terms = _tmp1_;
	g_variant_unref (_tmp0_);
	boxes_search_provider_GetInitialResultSet (self, terms, terms_length1, (GAsyncReadyCallback) _dbus_boxes_search_provider_GetInitialResultSet_ready, invocation);
	terms = (_vala_array_free (terms, terms_length1, (GDestroyNotify) g_free), NULL);
}


static void _dbus_boxes_search_provider_GetInitialResultSet_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	int result_length1 = 0;
	gchar** _tmp4_;
	GVariantBuilder _tmp5_;
	int _tmp6_;
	invocation = _user_data_;
	result = boxes_search_provider_GetInitialResultSet_finish ((BoxesSearchProvider*) source_object, _res_, &result_length1);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp4_ = result;
	g_variant_builder_init (&_tmp5_, G_VARIANT_TYPE ("as"));
	for (_tmp6_ = 0; _tmp6_ < result_length1; _tmp6_++) {
		g_variant_builder_add_value (&_tmp5_, g_variant_new_string (*_tmp4_));
		_tmp4_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp5_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_boxes_search_provider_GetSubsearchResultSet (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	gchar** previous_results = NULL;
	int previous_results_length1 = 0;
	GVariant* _tmp7_;
	gchar** _tmp8_;
	int _tmp8__length;
	int _tmp8__size;
	int _tmp8__length1;
	GVariantIter _tmp9_;
	GVariant* _tmp10_;
	gchar** new_terms = NULL;
	int new_terms_length1 = 0;
	GVariant* _tmp11_;
	gchar** _tmp12_;
	int _tmp12__length;
	int _tmp12__size;
	int _tmp12__length1;
	GVariantIter _tmp13_;
	GVariant* _tmp14_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp7_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp8_ = g_new (gchar*, 5);
	_tmp8__length = 0;
	_tmp8__size = 4;
	_tmp8__length1 = 0;
	g_variant_iter_init (&_tmp9_, _tmp7_);
	for (; (_tmp10_ = g_variant_iter_next_value (&_tmp9_)) != NULL; _tmp8__length1++) {
		if (_tmp8__size == _tmp8__length) {
			_tmp8__size = 2 * _tmp8__size;
			_tmp8_ = g_renew (gchar*, _tmp8_, _tmp8__size + 1);
		}
		_tmp8_[_tmp8__length++] = g_variant_dup_string (_tmp10_, NULL);
		g_variant_unref (_tmp10_);
	}
	previous_results_length1 = _tmp8__length1;
	_tmp8_[_tmp8__length] = NULL;
	previous_results = _tmp8_;
	g_variant_unref (_tmp7_);
	_tmp11_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp12_ = g_new (gchar*, 5);
	_tmp12__length = 0;
	_tmp12__size = 4;
	_tmp12__length1 = 0;
	g_variant_iter_init (&_tmp13_, _tmp11_);
	for (; (_tmp14_ = g_variant_iter_next_value (&_tmp13_)) != NULL; _tmp12__length1++) {
		if (_tmp12__size == _tmp12__length) {
			_tmp12__size = 2 * _tmp12__size;
			_tmp12_ = g_renew (gchar*, _tmp12_, _tmp12__size + 1);
		}
		_tmp12_[_tmp12__length++] = g_variant_dup_string (_tmp14_, NULL);
		g_variant_unref (_tmp14_);
	}
	new_terms_length1 = _tmp12__length1;
	_tmp12_[_tmp12__length] = NULL;
	new_terms = _tmp12_;
	g_variant_unref (_tmp11_);
	boxes_search_provider_GetSubsearchResultSet (self, previous_results, previous_results_length1, new_terms, new_terms_length1, (GAsyncReadyCallback) _dbus_boxes_search_provider_GetSubsearchResultSet_ready, invocation);
	previous_results = (_vala_array_free (previous_results, previous_results_length1, (GDestroyNotify) g_free), NULL);
	new_terms = (_vala_array_free (new_terms, new_terms_length1, (GDestroyNotify) g_free), NULL);
}


static void _dbus_boxes_search_provider_GetSubsearchResultSet_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	int result_length1 = 0;
	gchar** _tmp15_;
	GVariantBuilder _tmp16_;
	int _tmp17_;
	invocation = _user_data_;
	result = boxes_search_provider_GetSubsearchResultSet_finish ((BoxesSearchProvider*) source_object, _res_, &result_length1);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp15_ = result;
	g_variant_builder_init (&_tmp16_, G_VARIANT_TYPE ("as"));
	for (_tmp17_ = 0; _tmp17_ < result_length1; _tmp17_++) {
		g_variant_builder_add_value (&_tmp16_, g_variant_new_string (*_tmp15_));
		_tmp15_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp16_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_boxes_search_provider_get_metas (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	gchar** ids = NULL;
	int ids_length1 = 0;
	GVariant* _tmp18_;
	gchar** _tmp19_;
	int _tmp19__length;
	int _tmp19__size;
	int _tmp19__length1;
	GVariantIter _tmp20_;
	GVariant* _tmp21_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp18_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp19_ = g_new (gchar*, 5);
	_tmp19__length = 0;
	_tmp19__size = 4;
	_tmp19__length1 = 0;
	g_variant_iter_init (&_tmp20_, _tmp18_);
	for (; (_tmp21_ = g_variant_iter_next_value (&_tmp20_)) != NULL; _tmp19__length1++) {
		if (_tmp19__size == _tmp19__length) {
			_tmp19__size = 2 * _tmp19__size;
			_tmp19_ = g_renew (gchar*, _tmp19_, _tmp19__size + 1);
		}
		_tmp19_[_tmp19__length++] = g_variant_dup_string (_tmp21_, NULL);
		g_variant_unref (_tmp21_);
	}
	ids_length1 = _tmp19__length1;
	_tmp19_[_tmp19__length] = NULL;
	ids = _tmp19_;
	g_variant_unref (_tmp18_);
	boxes_search_provider_get_metas (self, ids, ids_length1, (GAsyncReadyCallback) _dbus_boxes_search_provider_get_metas_ready, invocation);
	ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
}


static void _dbus_boxes_search_provider_get_metas_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	GHashTable** result;
	int result_length1 = 0;
	GHashTable** _tmp22_;
	GVariantBuilder _tmp23_;
	int _tmp24_;
	invocation = _user_data_;
	result = boxes_search_provider_get_metas_finish ((BoxesSearchProvider*) source_object, _res_, &result_length1);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp22_ = result;
	g_variant_builder_init (&_tmp23_, G_VARIANT_TYPE ("aa{sv}"));
	for (_tmp24_ = 0; _tmp24_ < result_length1; _tmp24_++) {
		GVariantBuilder _tmp25_;
		GHashTableIter _tmp26_;
		gpointer _tmp27_;
		gpointer _tmp28_;
		g_hash_table_iter_init (&_tmp26_, *_tmp22_);
		g_variant_builder_init (&_tmp25_, G_VARIANT_TYPE ("a{sv}"));
		while (g_hash_table_iter_next (&_tmp26_, &_tmp27_, &_tmp28_)) {
			gchar* _key;
			GVariant* _value;
			_key = (gchar*) _tmp27_;
			_value = (GVariant*) _tmp28_;
			g_variant_builder_add (&_tmp25_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
		}
		g_variant_builder_add_value (&_tmp23_, g_variant_builder_end (&_tmp25_));
		_tmp22_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp23_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_hash_table_unref), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_boxes_search_provider_GetResultMetas (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	gchar** ids = NULL;
	int ids_length1 = 0;
	GVariant* _tmp29_;
	gchar** _tmp30_;
	int _tmp30__length;
	int _tmp30__size;
	int _tmp30__length1;
	GVariantIter _tmp31_;
	GVariant* _tmp32_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp29_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp30_ = g_new (gchar*, 5);
	_tmp30__length = 0;
	_tmp30__size = 4;
	_tmp30__length1 = 0;
	g_variant_iter_init (&_tmp31_, _tmp29_);
	for (; (_tmp32_ = g_variant_iter_next_value (&_tmp31_)) != NULL; _tmp30__length1++) {
		if (_tmp30__size == _tmp30__length) {
			_tmp30__size = 2 * _tmp30__size;
			_tmp30_ = g_renew (gchar*, _tmp30_, _tmp30__size + 1);
		}
		_tmp30_[_tmp30__length++] = g_variant_dup_string (_tmp32_, NULL);
		g_variant_unref (_tmp32_);
	}
	ids_length1 = _tmp30__length1;
	_tmp30_[_tmp30__length] = NULL;
	ids = _tmp30_;
	g_variant_unref (_tmp29_);
	boxes_search_provider_GetResultMetas (self, ids, ids_length1, (GAsyncReadyCallback) _dbus_boxes_search_provider_GetResultMetas_ready, invocation);
	ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
}


static void _dbus_boxes_search_provider_GetResultMetas_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	GHashTable** result;
	int result_length1 = 0;
	GHashTable** _tmp33_;
	GVariantBuilder _tmp34_;
	int _tmp35_;
	invocation = _user_data_;
	result = boxes_search_provider_GetResultMetas_finish ((BoxesSearchProvider*) source_object, _res_, &result_length1);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp33_ = result;
	g_variant_builder_init (&_tmp34_, G_VARIANT_TYPE ("aa{sv}"));
	for (_tmp35_ = 0; _tmp35_ < result_length1; _tmp35_++) {
		GVariantBuilder _tmp36_;
		GHashTableIter _tmp37_;
		gpointer _tmp38_;
		gpointer _tmp39_;
		g_hash_table_iter_init (&_tmp37_, *_tmp33_);
		g_variant_builder_init (&_tmp36_, G_VARIANT_TYPE ("a{sv}"));
		while (g_hash_table_iter_next (&_tmp37_, &_tmp38_, &_tmp39_)) {
			gchar* _key;
			GVariant* _value;
			_key = (gchar*) _tmp38_;
			_value = (GVariant*) _tmp39_;
			g_variant_builder_add (&_tmp36_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
		}
		g_variant_builder_add_value (&_tmp34_, g_variant_builder_end (&_tmp36_));
		_tmp33_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp34_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_hash_table_unref), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_boxes_search_provider_ActivateResult (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gchar* search_id = NULL;
	GVariant* _tmp40_;
	gchar** terms = NULL;
	int terms_length1 = 0;
	GVariant* _tmp41_;
	gchar** _tmp42_;
	int _tmp42__length;
	int _tmp42__size;
	int _tmp42__length1;
	GVariantIter _tmp43_;
	GVariant* _tmp44_;
	guint32 timestamp = 0U;
	GVariant* _tmp45_;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp40_ = g_variant_iter_next_value (&_arguments_iter);
	search_id = g_variant_dup_string (_tmp40_, NULL);
	g_variant_unref (_tmp40_);
	_tmp41_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp42_ = g_new (gchar*, 5);
	_tmp42__length = 0;
	_tmp42__size = 4;
	_tmp42__length1 = 0;
	g_variant_iter_init (&_tmp43_, _tmp41_);
	for (; (_tmp44_ = g_variant_iter_next_value (&_tmp43_)) != NULL; _tmp42__length1++) {
		if (_tmp42__size == _tmp42__length) {
			_tmp42__size = 2 * _tmp42__size;
			_tmp42_ = g_renew (gchar*, _tmp42_, _tmp42__size + 1);
		}
		_tmp42_[_tmp42__length++] = g_variant_dup_string (_tmp44_, NULL);
		g_variant_unref (_tmp44_);
	}
	terms_length1 = _tmp42__length1;
	_tmp42_[_tmp42__length] = NULL;
	terms = _tmp42_;
	g_variant_unref (_tmp41_);
	_tmp45_ = g_variant_iter_next_value (&_arguments_iter);
	timestamp = g_variant_get_uint32 (_tmp45_);
	g_variant_unref (_tmp45_);
	boxes_search_provider_ActivateResult (self, search_id, terms, terms_length1, timestamp);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	_g_free0 (search_id);
	terms = (_vala_array_free (terms, terms_length1, (GDestroyNotify) g_free), NULL);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_boxes_search_provider_LaunchSearch (BoxesSearchProvider* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gchar** terms = NULL;
	int terms_length1 = 0;
	GVariant* _tmp46_;
	gchar** _tmp47_;
	int _tmp47__length;
	int _tmp47__size;
	int _tmp47__length1;
	GVariantIter _tmp48_;
	GVariant* _tmp49_;
	guint32 timestamp = 0U;
	GVariant* _tmp50_;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp46_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp47_ = g_new (gchar*, 5);
	_tmp47__length = 0;
	_tmp47__size = 4;
	_tmp47__length1 = 0;
	g_variant_iter_init (&_tmp48_, _tmp46_);
	for (; (_tmp49_ = g_variant_iter_next_value (&_tmp48_)) != NULL; _tmp47__length1++) {
		if (_tmp47__size == _tmp47__length) {
			_tmp47__size = 2 * _tmp47__size;
			_tmp47_ = g_renew (gchar*, _tmp47_, _tmp47__size + 1);
		}
		_tmp47_[_tmp47__length++] = g_variant_dup_string (_tmp49_, NULL);
		g_variant_unref (_tmp49_);
	}
	terms_length1 = _tmp47__length1;
	_tmp47_[_tmp47__length] = NULL;
	terms = _tmp47_;
	g_variant_unref (_tmp46_);
	_tmp50_ = g_variant_iter_next_value (&_arguments_iter);
	timestamp = g_variant_get_uint32 (_tmp50_);
	g_variant_unref (_tmp50_);
	boxes_search_provider_LaunchSearch (self, terms, terms_length1, timestamp);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	terms = (_vala_array_free (terms, terms_length1, (GDestroyNotify) g_free), NULL);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void boxes_search_provider_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "GetInitialResultSet") == 0) {
		_dbus_boxes_search_provider_GetInitialResultSet (object, parameters, invocation);
	} else if (strcmp (method_name, "GetSubsearchResultSet") == 0) {
		_dbus_boxes_search_provider_GetSubsearchResultSet (object, parameters, invocation);
	} else if (strcmp (method_name, "GetMetas") == 0) {
		_dbus_boxes_search_provider_get_metas (object, parameters, invocation);
	} else if (strcmp (method_name, "GetResultMetas") == 0) {
		_dbus_boxes_search_provider_GetResultMetas (object, parameters, invocation);
	} else if (strcmp (method_name, "ActivateResult") == 0) {
		_dbus_boxes_search_provider_ActivateResult (object, parameters, invocation);
	} else if (strcmp (method_name, "LaunchSearch") == 0) {
		_dbus_boxes_search_provider_LaunchSearch (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* _dbus_boxes_search_provider_get_loaded (BoxesSearchProvider* self) {
	gboolean result;
	GVariant* _reply;
	result = boxes_search_provider_get_loaded (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}


static GVariant* boxes_search_provider_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "Loaded") == 0) {
		return _dbus_boxes_search_provider_get_loaded (object);
	}
	return NULL;
}


static void _dbus_boxes_search_provider_set_loaded (BoxesSearchProvider* self, GVariant* _value) {
	gboolean value = FALSE;
	value = g_variant_get_boolean (_value);
	boxes_search_provider_set_loaded (self, value);
}


static gboolean boxes_search_provider_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "Loaded") == 0) {
		_dbus_boxes_search_provider_set_loaded (object, value);
		return TRUE;
	}
	return FALSE;
}


guint boxes_search_provider_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_search_provider_dbus_interface_info), &_boxes_search_provider_dbus_interface_vtable, data, _boxes_search_provider_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}


static void _boxes_search_provider_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


BoxesSearchProviderApp* boxes_search_provider_app_construct (GType object_type) {
	BoxesSearchProviderApp * self = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = (BoxesSearchProviderApp*) g_object_new (object_type, "application-id", "org.gnome.Boxes.SearchProvider", "flags", G_APPLICATION_IS_SERVICE, "inactivity-timeout", 10000, NULL);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return self;
#line 4227 "gnome-boxes-search-provider.c"
}


BoxesSearchProviderApp* boxes_search_provider_app_new (void) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return boxes_search_provider_app_construct (BOXES_TYPE_SEARCH_PROVIDER_APP);
#line 4234 "gnome-boxes-search-provider.c"
}


static gboolean boxes_search_provider_app_real_dbus_register (GApplication* base, GDBusConnection* connection, const gchar* object_path, GError** error) {
	BoxesSearchProviderApp * self;
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = (BoxesSearchProviderApp*) base;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (connection != NULL, FALSE);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	g_return_val_if_fail (object_path != NULL, FALSE);
#line 4248 "gnome-boxes-search-provider.c"
	{
		GDBusConnection* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		BoxesSearchProvider* _tmp2_ = NULL;
		BoxesSearchProvider* _tmp3_ = NULL;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp0_ = connection;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp1_ = object_path;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp2_ = boxes_search_provider_new (self);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp3_ = _tmp2_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		boxes_search_provider_register_object (_tmp3_, _tmp0_, _tmp1_, &_inner_error_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_object_unref0 (_tmp3_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 4270 "gnome-boxes-search-provider.c"
				goto __catch3_g_io_error;
			}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			g_clear_error (&_inner_error_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
			return FALSE;
#line 4279 "gnome-boxes-search-provider.c"
		}
	}
	goto __finally3;
	__catch3_g_io_error:
	{
		GError* _error_ = NULL;
		FILE* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_error_ = _inner_error_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_inner_error_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp4_ = stderr;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp5_ = _error_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_tmp6_ = _tmp5_->message;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		fprintf (_tmp4_, "Could not register service: %s", _tmp6_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_application_quit ((GApplication*) self);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		_g_error_free0 (_error_);
#line 4305 "gnome-boxes-search-provider.c"
	}
	__finally3:
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_clear_error (&_inner_error_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		return FALSE;
#line 4316 "gnome-boxes-search-provider.c"
	}
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = TRUE;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 4322 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_app_real_startup (GApplication* base) {
	BoxesSearchProviderApp * self;
	const gchar* _tmp0_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	self = (BoxesSearchProviderApp*) base;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = g_getenv ("BOXES_SEARCH_PROVIDER_PERSIST");
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	if (_tmp0_ != NULL) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
		g_application_hold ((GApplication*) self);
#line 4337 "gnome-boxes-search-provider.c"
	}
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	G_APPLICATION_CLASS (boxes_search_provider_app_parent_class)->startup (G_TYPE_CHECK_INSTANCE_CAST (self, g_application_get_type (), GApplication));
#line 4341 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_app_class_init (BoxesSearchProviderAppClass * klass) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	boxes_search_provider_app_parent_class = g_type_class_peek_parent (klass);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	((GApplicationClass *) klass)->dbus_register = boxes_search_provider_app_real_dbus_register;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	((GApplicationClass *) klass)->startup = boxes_search_provider_app_real_startup;
#line 4352 "gnome-boxes-search-provider.c"
}


static void boxes_search_provider_app_instance_init (BoxesSearchProviderApp * self) {
}


GType boxes_search_provider_app_get_type (void) {
	static volatile gsize boxes_search_provider_app_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_search_provider_app_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSearchProviderAppClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_search_provider_app_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSearchProviderApp), 0, (GInstanceInitFunc) boxes_search_provider_app_instance_init, NULL };
		GType boxes_search_provider_app_type_id;
		boxes_search_provider_app_type_id = g_type_register_static (g_application_get_type (), "BoxesSearchProviderApp", &g_define_type_info, 0);
		g_once_init_leave (&boxes_search_provider_app_type_id__volatile, boxes_search_provider_app_type_id);
	}
	return boxes_search_provider_app_type_id__volatile;
}


gint _vala_main (void) {
	gint result = 0;
	BoxesSearchProviderApp* _tmp0_ = NULL;
	BoxesSearchProviderApp* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp0_ = boxes_search_provider_app_new ();
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp1_ = _tmp0_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp2_ = g_application_run ((GApplication*) _tmp1_, 0, NULL);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_tmp3_ = _tmp2_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	_g_object_unref0 (_tmp1_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	result = _tmp3_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return result;
#line 4392 "gnome-boxes-search-provider.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/gnome-boxes-search-provider.vala"
	return _vala_main ();
#line 4402 "gnome-boxes-search-provider.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



